==> chaosmesh-model-5.0.3-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodStatusBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodStatusBuilder extends PodStatusFluentImpl<PodStatusBuilder> implements VisitableBuilder<PodStatus,PodStatusBuilder> {

    PodStatusFluent<?> fluent;
    Boolean validationEnabled;

    public PodStatusBuilder() {
        this(true);
    }

    public PodStatusBuilder(Boolean validationEnabled) {
        this(new PodStatus(), validationEnabled);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodStatus(), validationEnabled);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance) {
        this(fluent, instance, true);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withHostIP(instance.getHostIP()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withName(instance.getName()); 
        fluent.withNamespace(instance.getNamespace()); 
        fluent.withPodIP(instance.getPodIP()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodStatusBuilder(PodStatus instance) {
        this(instance,true);
    }

    public PodStatusBuilder(PodStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withHostIP(instance.getHostIP()); 
        this.withMessage(instance.getMessage()); 
        this.withName(instance.getName()); 
        this.withNamespace(instance.getNamespace()); 
        this.withPodIP(instance.getPodIP()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodStatus build() {
        EditablePodStatus buildable = new EditablePodStatus(fluent.getAction(),fluent.getHostIP(),fluent.getMessage(),fluent.getName(),fluent.getNamespace(),fluent.getPodIP());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodStatusBuilder that = (PodStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodStatusBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodStatusBuilder extends PodStatusFluentImpl<PodStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<PodStatus,PodStatusBuilder> {

    PodStatusFluent<?> fluent;
    Boolean validationEnabled;

    public PodStatusBuilder() {
        this(true);
    }

    public PodStatusBuilder(Boolean validationEnabled) {
        this(new PodStatus(), validationEnabled);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodStatus(), validationEnabled);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance) {
        this(fluent, instance, true);
    }

    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withHostIP(instance.getHostIP()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withName(instance.getName()); 
        fluent.withNamespace(instance.getNamespace()); 
        fluent.withPodIP(instance.getPodIP()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodStatusBuilder(PodStatus instance) {
        this(instance,true);
    }

    public PodStatusBuilder(PodStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withHostIP(instance.getHostIP()); 
        this.withMessage(instance.getMessage()); 
        this.withName(instance.getName()); 
        this.withNamespace(instance.getNamespace()); 
        this.withPodIP(instance.getPodIP()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodStatus build() {
        EditablePodStatus buildable = new EditablePodStatus(fluent.getAction(),fluent.getHostIP(),fluent.getMessage(),fluent.getName(),fluent.getNamespace(),fluent.getPodIP());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodStatusBuilder that = (PodStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
